@@ -27,7 +27,6 @@
  *
  * Authors: Alexander Gottwald	
  */
-/* $XFree86: xc/programs/Xserver/hw/xwin/winconfig.c,v 1.3 2003/10/02 13:30:10 eich Exp $ */
 
 #ifdef HAVE_XWIN_CONFIG_H
 #include <xwin-config.h>
@@ -37,12 +36,7 @@
 #include "winmsg.h"
 #include "globals.h"
 
-#ifdef XKB
-#ifndef XKB_IN_SERVER
-#define XKB_IN_SERVER
-#endif
-#include <X11/extensions/XKBsrv.h>
-#endif
+#include "xkbsrv.h"
 
 #ifdef XWIN_XF86CONFIG
 #ifndef CONFIGPATH
@@ -50,7 +44,6 @@
                     "/etc/X11/%R," "%P/etc/X11/%R," \
                     "%E," "%F," \
                     "/etc/X11/%F," "%P/etc/X11/%F," \
-                    "%D/%X," \
                     "/etc/X11/%X-%M," "/etc/X11/%X," "/etc/%X," \
                     "%P/etc/X11/%X.%H," "%P/etc/X11/%X-%M," \
                     "%P/etc/X11/%X," \
@@ -66,19 +59,14 @@ WinCmdlineRec g_cmdline = {
   NULL,				/* configFile */
 #endif
   NULL,				/* fontPath */
-  NULL,				/* rgbPath */
 #ifdef XWIN_XF86CONFIG
   NULL,				/* keyboard */
 #endif
-#ifdef XKB
-  FALSE,			/* noXkbExtension */
-  NULL,				/* xkbMap */
   NULL,             /* xkbRules */
   NULL,             /* xkbModel */
   NULL,             /* xkbLayout */
   NULL,             /* xkbVariant */
   NULL,             /* xkbOptions */
-#endif
   NULL,				/* screenname */
   NULL,				/* mousename */
   FALSE,			/* emulate3Buttons */
@@ -90,24 +78,14 @@ winInfoRec g_winInfo = {
    0,				/* leds */
    500,				/* delay */
    30				/* rate */
-#ifdef XKB
    }
   ,
   {				/* xkb */
-   FALSE,			/* disable */
    NULL,			/* rules */
    NULL,			/* model */
    NULL,			/* layout */
    NULL,			/* variant */
    NULL,			/* options */
-   NULL,			/* initialMap */
-   NULL,			/* keymap */
-   NULL,			/* types */
-   NULL,			/* compat */
-   NULL,			/* keycodes */
-   NULL,			/* symbols */
-   NULL				/* geometry */
-#endif
    }
   ,
   {
@@ -231,11 +209,9 @@ winReadConfigfile ()
 Bool
 winConfigKeyboard (DeviceIntPtr pDevice)
 {
-#ifdef XKB
   char                          layoutName[KL_NAMELENGTH];
   static unsigned int           layoutNum = 0;
   int                           keyboardType;
-#endif
 #ifdef XWIN_XF86CONFIG
   XF86ConfInputPtr		kbd = NULL;
   XF86ConfInputPtr		input_list = NULL;
@@ -245,26 +221,10 @@ winConfigKeyboard (DeviceIntPtr pDevice)
   char				*s = NULL;
 
   /* Setup defaults */
-#ifdef XKB
-  g_winInfo.xkb.disable = FALSE;
-# ifdef PC98 /* japanese */	/* not implemented */
-  g_winInfo.xkb.rules = "xfree98";
-  g_winInfo.xkb.model = "pc98";
-  g_winInfo.xkb.layout = "nex/jp";
-  g_winInfo.xkb.variant = NULL;
-  g_winInfo.xkb.options = NULL;
-# else
-  g_winInfo.xkb.rules = "xorg";
-  g_winInfo.xkb.model = "pc101";
-  g_winInfo.xkb.layout = "us";
-  g_winInfo.xkb.variant = NULL;
-  g_winInfo.xkb.options = NULL;
-# endif	/* PC98 */
+  XkbGetRulesDflts(&g_winInfo.xkb);
 
   /*
    * Query the windows autorepeat settings and change the xserver defaults.   
-   * If XKB is disabled then windows handles the autorepeat and the special 
-   * treatment is not needed
    */
   {
     int kbd_delay;
@@ -361,15 +321,6 @@ winConfigKeyboard (DeviceIntPtr pDevice)
       }
   }  
   
-  g_winInfo.xkb.initialMap = NULL;
-  g_winInfo.xkb.keymap = NULL;
-  g_winInfo.xkb.types = NULL;
-  g_winInfo.xkb.compat = NULL;
-  g_winInfo.xkb.keycodes = NULL;
-  g_winInfo.xkb.symbols = NULL;
-  g_winInfo.xkb.geometry = NULL;
-#endif /* XKB */
-
   /* parse the configuration */
 #ifdef XWIN_XF86CONFIG
   if (g_cmdline.keyboard)
@@ -421,179 +372,101 @@ winConfigKeyboard (DeviceIntPtr pDevice)
         }
 #endif
       
-#ifdef XKB
-      from = X_DEFAULT;
-      if (g_cmdline.noXkbExtension)
-	{
-	  from = X_CMDLINE;
-	  g_winInfo.xkb.disable = TRUE;
-	}
+        s = NULL;
+        if (g_cmdline.xkbRules)
+          {
+            s = g_cmdline.xkbRules;
+            from = X_CMDLINE;
+          }
 #ifdef XWIN_XF86CONFIG
-      else if (kbd->inp_option_lst)
-	{
-	  int b = winSetBoolOption (kbd->inp_option_lst, "XkbDisable", FALSE);
-	  if (b)
-	    {
-	      from = X_CONFIG;
-	      g_winInfo.xkb.disable = TRUE;
-	    }
-	}
+        else
+          {
+            s = winSetStrOption (kbd->inp_option_lst, "XkbRules", NULL);
+            from = X_CONFIG;
+          }
 #endif
-      if (g_winInfo.xkb.disable)
-	{
-	  winMsg (from, "XkbExtension disabled\n");
-	}
-      else
-	{
-          s = NULL;  
-          if (g_cmdline.xkbRules)
-            {
-              s = g_cmdline.xkbRules;
-              from = X_CMDLINE;  
-            }
-#ifdef XWIN_XF86CONFIG
-          else 
-            {
-              s = winSetStrOption (kbd->inp_option_lst, "XkbRules", NULL);
-              from = X_CONFIG;  
-            }
-#endif
-          if (s)
-	    {
-	      g_winInfo.xkb.rules = NULL_IF_EMPTY (s);
-	      winMsg (from, "XKB: rules: \"%s\"\n", s);
-	    }
+        if (s)
+          {
+            g_winInfo.xkb.rules = NULL_IF_EMPTY (s);
+            winMsg (from, "XKB: rules: \"%s\"\n", s);
+	  }
           
-          s = NULL;
-          if (g_cmdline.xkbModel)
-            {
-              s = g_cmdline.xkbModel;
-              from = X_CMDLINE;
-            }
+        s = NULL;
+        if (g_cmdline.xkbModel)
+          {
+            s = g_cmdline.xkbModel;
+            from = X_CMDLINE;
+          }
 #ifdef XWIN_XF86CONFIG
-          else
-            {
-              s = winSetStrOption (kbd->inp_option_lst, "XkbModel", NULL);
-              from = X_CONFIG;
-            }  
+        else
+          {
+            s = winSetStrOption (kbd->inp_option_lst, "XkbModel", NULL);
+            from = X_CONFIG;
+          }
 #endif
-	  if (s)
-	    {
-	      g_winInfo.xkb.model = NULL_IF_EMPTY (s);
-	      winMsg (from, "XKB: model: \"%s\"\n", s);
-	    }
+        if (s)
+	  {
+	    g_winInfo.xkb.model = NULL_IF_EMPTY (s);
+	    winMsg (from, "XKB: model: \"%s\"\n", s);
+	  }
 
-          s = NULL;
-          if (g_cmdline.xkbLayout)
-            {
-              s = g_cmdline.xkbLayout;
-              from = X_CMDLINE;
-            }
+        s = NULL;
+        if (g_cmdline.xkbLayout)
+          {
+            s = g_cmdline.xkbLayout;
+            from = X_CMDLINE;
+          }
 #ifdef XWIN_XF86CONFIG
-          else
-            {
-              s = winSetStrOption (kbd->inp_option_lst, "XkbLayout", NULL);
-              from = X_CONFIG;
-            }
+        else
+          {
+            s = winSetStrOption (kbd->inp_option_lst, "XkbLayout", NULL);
+            from = X_CONFIG;
+          }
 #endif
-          if (s)  
-	    {
-	      g_winInfo.xkb.layout = NULL_IF_EMPTY (s);
-	      winMsg (from, "XKB: layout: \"%s\"\n", s);
-	    }
+        if (s)
+          {
+	    g_winInfo.xkb.layout = NULL_IF_EMPTY (s);
+	    winMsg (from, "XKB: layout: \"%s\"\n", s);
+	  }
 
-          s = NULL;
-          if (g_cmdline.xkbVariant)
-            {
-              s = g_cmdline.xkbVariant;
-              from = X_CMDLINE;
-            }
+        s = NULL;
+        if (g_cmdline.xkbVariant)
+          {
+            s = g_cmdline.xkbVariant;
+            from = X_CMDLINE;
+          }
 #ifdef XWIN_XF86CONFIG
-          else
-            { 
-              s = winSetStrOption (kbd->inp_option_lst, "XkbVariant", NULL);
-              from = X_CONFIG;
-            }
+        else
+          {
+            s = winSetStrOption (kbd->inp_option_lst, "XkbVariant", NULL);
+            from = X_CONFIG;
+          }
 #endif
-	  if (s)
-	    {
-	      g_winInfo.xkb.variant = NULL_IF_EMPTY (s);
-	      winMsg (from, "XKB: variant: \"%s\"\n", s);
-	    }
+	if (s)
+	  {
+	    g_winInfo.xkb.variant = NULL_IF_EMPTY (s);
+	    winMsg (from, "XKB: variant: \"%s\"\n", s);
+	  }
 
-          s = NULL;
-          if (g_cmdline.xkbOptions)
-            {
-              s = g_cmdline.xkbOptions;
-              from = X_CMDLINE;
-            }
+        s = NULL;
+        if (g_cmdline.xkbOptions)
+          {
+            s = g_cmdline.xkbOptions;
+            from = X_CMDLINE;
+          }
 #ifdef XWIN_XF86CONFIG
-          else
-            { 
-              s = winSetStrOption (kbd->inp_option_lst, "XkbOptions", NULL);
-              from = X_CONFIG;
-            }
+        else
+          {
+            s = winSetStrOption (kbd->inp_option_lst, "XkbOptions", NULL);
+            from = X_CONFIG;
+          }
 #endif
-          if (s)
-	    {
-	      g_winInfo.xkb.options = NULL_IF_EMPTY (s);
-	      winMsg (from, "XKB: options: \"%s\"\n", s);
-	    }
+        if (s)
+	  {
+	    g_winInfo.xkb.options = NULL_IF_EMPTY (s);
+	    winMsg (from, "XKB: options: \"%s\"\n", s);
+	  }
 
-#ifdef XWIN_XF86CONFIG
-	  from = X_CMDLINE;
-	  if (!XkbInitialMap)
-	    {
-	      s =
-		winSetStrOption (kbd->inp_option_lst, "XkbInitialMap", NULL);
-	      if (s)
-		{
-		  XkbInitialMap = NULL_IF_EMPTY (s);
-		  from = X_CONFIG;
-		}
-	    }
-
-	  if ((s = winSetStrOption (kbd->inp_option_lst, "XkbKeymap", NULL)))
-	    {
-	      g_winInfo.xkb.keymap = NULL_IF_EMPTY (s);
-	      winMsg (X_CONFIG, "XKB: keymap: \"%s\" "
-		      " (overrides other XKB settings)\n", s);
-	    }
-
-	  if ((s = winSetStrOption (kbd->inp_option_lst, "XkbCompat", NULL)))
-	    {
-	      g_winInfo.xkb.compat = NULL_IF_EMPTY (s);
-	      winMsg (X_CONFIG, "XKB: compat: \"%s\"\n", s);
-	    }
-
-	  if ((s = winSetStrOption (kbd->inp_option_lst, "XkbTypes", NULL)))
-	    {
-	      g_winInfo.xkb.types = NULL_IF_EMPTY (s);
-	      winMsg (X_CONFIG, "XKB: types: \"%s\"\n", s);
-	    }
-
-	  if ((s =
-	       winSetStrOption (kbd->inp_option_lst, "XkbKeycodes", NULL)))
-	    {
-	      g_winInfo.xkb.keycodes = NULL_IF_EMPTY (s);
-	      winMsg (X_CONFIG, "XKB: keycodes: \"%s\"\n", s);
-	    }
-
-	  if ((s =
-	       winSetStrOption (kbd->inp_option_lst, "XkbGeometry", NULL)))
-	    {
-	      g_winInfo.xkb.geometry = NULL_IF_EMPTY (s);
-	      winMsg (X_CONFIG, "XKB: geometry: \"%s\"\n", s);
-	    }
-
-	  if ((s = winSetStrOption (kbd->inp_option_lst, "XkbSymbols", NULL)))
-	    {
-	      g_winInfo.xkb.symbols = NULL_IF_EMPTY (s);
-	      winMsg (X_CONFIG, "XKB: symbols: \"%s\"\n", s);
-	    }
-#endif
-#endif
-	}
 #ifdef XWIN_XF86CONFIG
     }
 #endif
@@ -684,28 +557,12 @@ winConfigFiles ()
     }
   winMsg (from, "FontPath set to \"%s\"\n", defaultFontPath);
 
-  /* RGBPath */
-  from = X_DEFAULT;
-  if (g_cmdline.rgbPath)
-    {
-      from = X_CMDLINE;
-      rgbPath = g_cmdline.rgbPath;
-    }
-  else if (filesptr != NULL && filesptr->file_rgbpath)
-    {
-      from = X_CONFIG;
-      rgbPath = xstrdup (filesptr->file_rgbpath);
-    }
-  winMsg (from, "RgbPath set to \"%s\"\n", rgbPath);
-
   return TRUE;
 }
 #else
 Bool
-winConfigFiles ()
+winConfigFiles (void)
 {
-  MessageType from;
-
   /* Fontpath */
   if (g_cmdline.fontPath)
     {
@@ -713,28 +570,20 @@ winConfigFiles ()
       winMsg (X_CMDLINE, "FontPath set to \"%s\"\n", defaultFontPath);
     }
 
-  /* RGBPath */
-  if (g_cmdline.rgbPath)
-    {
-      from = X_CMDLINE;
-      rgbPath = g_cmdline.rgbPath;
-      winMsg (X_CMDLINE, "RgbPath set to \"%s\"\n", rgbPath);
-    }
-
   return TRUE;
 }
 #endif
 
 
 Bool
-winConfigOptions ()
+winConfigOptions (void)
 {
   return TRUE;
 }
 
 
 Bool
-winConfigScreens ()
+winConfigScreens (void)
 {
   return TRUE;
 }
